diff --git a/Scripts/Bash/Functions/Identity/identity_render.sh b/Scripts/Bash/Functions/Identity/identity_render.sh
index c56a306..fa1300b 100755
--- a/Scripts/Bash/Functions/Identity/identity_render.sh
+++ b/Scripts/Bash/Functions/Identity/identity_render.sh
@@ -67,7 +67,7 @@ function identity_render {
 
         # Check variables passed from artwork-specific pre-rendition
         # configuration scripts and make required transformations.
-        identity_renderConfig
+        identity_getConfig
 
         # Redefine action value (ACTIONVAL) based on pre-rendition
         # configuration script path value. Otherwise, massive
diff --git a/Scripts/Bash/Functions/Identity/identity_renderBase.sh b/Scripts/Bash/Functions/Identity/identity_renderBase.sh
index 2b4205d..9ff4224 100755
--- a/Scripts/Bash/Functions/Identity/identity_renderBase.sh
+++ b/Scripts/Bash/Functions/Identity/identity_renderBase.sh
@@ -43,7 +43,7 @@ function identity_renderBase {
     PARENTDIR=$(basename "${ACTIONVAL}")
 
     # Define base location of template files.
-    identity_renderDirTemplate
+    identity_getDirTemplate
     
     # Define list of files to process. 
     FILES=$(cli_getFilesList "${TEMPLATE}" "${FLAG_FILTER}.*\.(svgz|svg)")
@@ -93,7 +93,7 @@ function identity_renderBase {
         fi
  
         # Define final location of output directory.
-        identity_renderDirOutput
+        identity_getDirOutput
 
         # Get relative path to file. The path string (stored in FILE)
         # has two parts: 1. the variable path and 2. the common path.
diff --git a/Scripts/Bash/Functions/Identity/identity_renderDm.sh b/Scripts/Bash/Functions/Identity/identity_renderDm.sh
index 6d182d7..bc7780e 100755
--- a/Scripts/Bash/Functions/Identity/identity_renderDm.sh
+++ b/Scripts/Bash/Functions/Identity/identity_renderDm.sh
@@ -58,7 +58,7 @@ function identity_renderDm {
 
     # Get display manager passed from render.conf.sh pre-rendition
     # configuration script.
-    DM=$(identity_renderConfigOption "${ACTION}" '2')
+    DM=$(identity_getConfigOption "${ACTION}" '2')
  
     # Sanitate display manager passed from render.conf.sh
     # pre-rendition configuration script. Whatever value be retrived
@@ -69,7 +69,7 @@ function identity_renderDm {
 
     # Get screen resolutions passed from render.conf.sh pre-rendition
     # configuration script.
-    RESOLUTIONS=$(identity_renderConfigOption "${ACTION}" '3')
+    RESOLUTIONS=$(identity_getConfigOption "${ACTION}" '3')
 
     # Check screen resolutions passed from render.conf.sh
     # pre-rendition configuration script.
diff --git a/Scripts/Bash/Functions/Identity/identity_renderFormats.sh b/Scripts/Bash/Functions/Identity/identity_renderFormats.sh
index 616a42c..65a9c30 100644
--- a/Scripts/Bash/Functions/Identity/identity_renderFormats.sh
+++ b/Scripts/Bash/Functions/Identity/identity_renderFormats.sh
@@ -30,7 +30,7 @@
 function identity_renderFormats {
 
     # Get image formats.
-    local FORMATS=$(identity_renderConfigOption "$2" '2-')
+    local FORMATS=$(identity_getConfigOption "$2" '2-')
 
     # Check base file existence.
     if [[ -f ${FILE}.png ]];then
diff --git a/Scripts/Bash/Functions/Identity/identity_renderGroupByType.sh b/Scripts/Bash/Functions/Identity/identity_renderGroupByType.sh
index 7d25aac..d4bddb3 100755
--- a/Scripts/Bash/Functions/Identity/identity_renderGroupByType.sh
+++ b/Scripts/Bash/Functions/Identity/identity_renderGroupByType.sh
@@ -69,7 +69,7 @@ function identity_renderGroupByType {
 
     # Sanitate file types passed from render.conf.sh pre-rendition
     # configuration script.
-    FORMATS=$(identity_renderConfigOption "$FORMATS" '2-')
+    FORMATS=$(identity_getConfigOption "$FORMATS" '2-')
 
     # Check file types passed from render.conf.sh pre-rendition
     # configuration script.
diff --git a/Scripts/Bash/Functions/Identity/identity_renderGrub.sh b/Scripts/Bash/Functions/Identity/identity_renderGrub.sh
index 90d3a34..c9ebecb 100644
--- a/Scripts/Bash/Functions/Identity/identity_renderGrub.sh
+++ b/Scripts/Bash/Functions/Identity/identity_renderGrub.sh
@@ -33,7 +33,7 @@ function identity_renderGrub {
     # configuration script. These options are applied to pnmremap when
     # doing color reduction, so any option available for pnmremap
     # command can be passed to renderSyslinux functionality.
-    local OPTIONS=$(identity_renderConfigOption "$ACTION" '2-')
+    local OPTIONS=$(identity_getConfigOption "$ACTION" '2-')
 
     # Re-define 16 colors images default file name prefix using
     # options as reference. This is useful to differenciate final
diff --git a/Scripts/Bash/Functions/Identity/identity_renderSyslinux.sh b/Scripts/Bash/Functions/Identity/identity_renderSyslinux.sh
index 97b24de..1346ac3 100755
--- a/Scripts/Bash/Functions/Identity/identity_renderSyslinux.sh
+++ b/Scripts/Bash/Functions/Identity/identity_renderSyslinux.sh
@@ -33,7 +33,7 @@ function identity_renderSyslinux {
     # configuration script. These options are applied to pnmremap when
     # doing color reduction, so any option available for pnmremap
     # command can be passed to renderSyslinux functionality.
-    local OPTIONS=$(identity_renderConfigOption "$ACTION" '2-')
+    local OPTIONS=$(identity_getConfigOption "$ACTION" '2-')
 
     # Check options passed to action. This is required in order to
     # aviod using options used already in this script. For example
diff --git a/Scripts/Bash/Functions/Identity/identity_getConfig.sh b/Scripts/Bash/Functions/Identity/identity_getConfig.sh
index 2143fa7..fe459a6 100755
--- a/Scripts/Bash/Functions/Identity/identity_getConfig.sh
+++ b/Scripts/Bash/Functions/Identity/identity_getConfig.sh
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
 # identity_renderConfig.sh -- This function checks/validates variables
 # passed from artwork-specific pre-rendition configuration files.
 #
 # Copyright (C) 2009-2011 Alain Reguera Delgado
@@ -24,7 +24,7 @@
 # $Id$
 # ----------------------------------------------------------------------
 
-function identity_renderConfig {
+function identity_getConfig {
 
     local POSTCOUNT=0
     local LASTCOUNT=0
@@ -37,13 +37,13 @@ function identity_renderConfig {
 
         # Define post-rendition actions.
         if [[ $ACTION =~ '^POST:' ]];then
-            ACTION=$(identity_renderConfigOption "$ACTION" '2-')
+            ACTION=$(identity_getConfigOption "$ACTION" '2-')
             POSTACTIONS[$POSTCOUNT]="$ACTION"
             POSTCOUNT=$(($POSTCOUNT + 1))
 
         # Define last-rendition actions.
         elif [[ $ACTION =~ '^LAST:' ]];then
-            ACTION=$(identity_renderConfigOption "$ACTION" '2-')
+            ACTION=$(identity_getConfigOption "$ACTION" '2-')
             LASTACTIONS[$LASTCOUNT]="$ACTION"
             LASTCOUNT=$(($LASTCOUNT + 1))
         fi
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# identity_renderConfig.sh -- This function checks/validates variables
+# identity_getConfig.sh -- This function checks/validates variables
 # passed from artwork-specific pre-rendition configuration files.
 #
diff --git a/Scripts/Bash/Functions/Identity/identity_getConfigOption.sh b/Scripts/Bash/Functions/Identity/identity_getConfigOption.sh
index fb4f95a..2c78ef9 100755
--- a/Scripts/Bash/Functions/Identity/identity_getConfigOption.sh
+++ b/Scripts/Bash/Functions/Identity/identity_getConfigOption.sh
@@ -1,14 +1,14 @@
 #!/bin/bash
 #
 # identity_renderConfigOption.sh -- This function standardizes the way
 # action values are retrived from pre-rendition configuration files.
 # Use this function whenever you need to retrive action values from
 # pre-rendition configuration script.
 #
-# Usage: VAR=$(identity_renderConfigOption "ACTION" "FIELD")
+# Usage: VAR=$(identity_getConfigOption "ACTION" "FIELD")
 #
 # VAR is the name of the variable where we store the option named
-# returned by identity_renderConfigOption. 
+# returned by identity_getConfigOption. 
 #
 # ACTION is the string definition set in the pre-rendition
 # configuration script that holds the action name and its options
@@ -41,7 +41,7 @@
 # $Id$
 # ----------------------------------------------------------------------
 
-function identity_renderConfigOption {
+function identity_getConfigOption {
 
     local ACTION="$1"
     local FIELD="$2"
@@ -1,14 +1,14 @@
 #!/bin/bash
 #
-# identity_renderConfigOption.sh -- This function standardizes the way
+# identity_getConfigOption.sh -- This function standardizes the way
 # action values are retrived from pre-rendition configuration files.
 # Use this function whenever you need to retrive action values from
diff --git a/Scripts/Bash/Functions/Identity/identity_getDirOutput.sh b/Scripts/Bash/Functions/Identity/identity_getDirOutput.sh
index 58ec731..7002aa9 100644
--- a/Scripts/Bash/Functions/Identity/identity_getDirOutput.sh
+++ b/Scripts/Bash/Functions/Identity/identity_getDirOutput.sh
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
 # identity_renderDirOutput.sh -- This function defines the final
 # absolute path the centos-art.sh script uses to store identity
 # contents produced at rendition time.
 #
@@ -25,7 +25,7 @@
 # $Id$
 # ----------------------------------------------------------------------
 
-function identity_renderDirOutput {
+function identity_getDirOutput {
 
     # Define base output directory using design model path as reference.
     OUTPUT=$(dirname $FILE | sed -r \
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# identity_renderDirOutput.sh -- This function defines the final
+# identity_getDirOutput.sh -- This function defines the final
 # absolute path the centos-art.sh script uses to store identity
 # contents produced at rendition time.
diff --git a/Scripts/Bash/Functions/Identity/identity_getDirTemplate.sh b/Scripts/Bash/Functions/Identity/identity_getDirTemplate.sh
index 88c563e..e6c1ef5 100644
--- a/Scripts/Bash/Functions/Identity/identity_getDirTemplate.sh
+++ b/Scripts/Bash/Functions/Identity/identity_getDirTemplate.sh
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
 # identity_renderDirTemplate.sh -- This function re-defines absolute
 # path to artwork's related design templates directory.
 #
 # Copyright (C) 2009-2011 Alain Reguera Delgado
@@ -24,7 +24,7 @@
 # $Id$
 # ----------------------------------------------------------------------
 
-function identity_renderDirTemplate {
+function identity_getDirTemplate {
 
     # Initialize design models location using action value as
     # reference.
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# identity_renderDirTemplate.sh -- This function re-defines absolute
+# identity_getDirTemplate.sh -- This function re-defines absolute
 # path to artwork's related design templates directory.
 #